#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-canon-lbp351-352-lipslx"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "Canon LBP351-352 LIPSLX" "Canon LBP6600 LIPSLX" "Canon LBP6700 LIPSLX" "Canon LBP6710 LIPSLX" "Canon LBP8630-8620-8610 LIPSLX" "Canon LBP8720-8710 LIPSLX" "Canon LBP8730 LIPSLX" "Canon LBP8900 LIPSLX" "Canon LBP712C LIPSLX" "Canon LBP7600C LIPSLX" "Canon LBP843C-842C-841C LIPSLX" "Canon LBP9510C LIPSLX" "Canon LBP9520C LIPSLX" "Canon LBP9650C LIPSLX" "Canon LBP9660C LIPSLX" "Canon LBP9950C-9900C LIPSLX" "Canon MF417 LIPSLX" "Canon MF510 Series LIPSLX" "Canon iR-ADV 4025-4035 LIPSLX" "Canon iR-ADV 4045 LIPSLX" "Canon iR-ADV 4225-4235 LIPSLX" "Canon iR-ADV 4245 LIPSLX" "Canon iR-ADV 4525-4535 LIPSLX" "Canon iR-ADV 4545 LIPSLX" "Canon iR-ADV 6055-6065 LIPSLX" "Canon iR-ADV 6075 LIPSLX" "Canon iR-ADV 6255-6265 LIPSLX" "Canon iR-ADV 6275 LIPSLX" "Canon iR-ADV 6555-6565 LIPSLX" "Canon iR-ADV 6560 LIPSLX" "Canon iR-ADV 6575 LIPSLX" "Canon iR-ADV 8085-8095 LIPSLX" "Canon iR-ADV 8105 LIPSLX" "Canon iR-ADV 8205 LIPSLX" "Canon iR-ADV 8285-8295 LIPSLX" "Canon iR-ADV 8505 LIPSLX" "Canon iR-ADV 8585-8595 LIPSLX" "Canon iR-ADV C2020-2030 LIPSLX" "Canon iR-ADV C2218 LIPSLX" "Canon iR-ADV C2220-2230 LIPSLX" "Canon iR-ADV C3320-3330 LIPSLX" "Canon iR-ADV C350 LIPSLX" "Canon iR-ADV C3520-3530 LIPSLX" "Canon iR-ADV C355 LIPSLX" "Canon iR-ADV C5030-5035 LIPSLX" "Canon iR-ADV C5045-5051 LIPSLX" "Canon iR-ADV C5235-5240 LIPSLX" "Canon iR-ADV C5250-5255 LIPSLX" "Canon iR-ADV C5535-5540 LIPSLX" "Canon iR-ADV C5550-5560 LIPSLX" "Canon iR-ADV C7055-7065 LIPSLX" "Canon iR-ADV C7260-7270 LIPSLX" "Canon iR-ADV C7565 LIPSLX" "Canon iR-ADV C7580-7570 LIPSLX" "Canon iR-ADV C9065 LIPSLX" "Canon iR-ADV C9075 LIPSLX" "Canon iR-ADV C9270-9280 LIPSLX" "Canon iPR C6010 LIPSLX" "Canon iPR C650 LIPSLX" "Canon iPR C700-800 LIPSLX" "Canon iPR C7010VP LIPSLX" "Canon iPR C750-850 LIPSLX" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
